
.. _salt-pillars:

=======
Pillars
=======

Salt includes a number of built-in external pillars, listed at
:ref:`all-salt.pillars`.

The below links contain documentation for the configuration options

- :ref:`master-side configuration <pillar-configuration-master>`
- :ref:`minion-side configuration <pillar-configuration-minion>`

Note that some of same the configuration options from the master are present in
the minion configuration file, these are used in :ref:`masterless
<tutorial-standalone-minion>` mode.

The source for the built-in Salt pillars can be found here:
:blob:`salt/pillar`
